
#include <avr/io.h>
#include <util/delay.h>
#include <avr/pgmspace.h>
#include "keypad.h"
#include "lcd.h"

#define DRIVER1_MS1 PD0
#define DRIVER1_MS2 PD1
/*	
ms1 	ms2t
LOW 	LOW	FULL
HIGH 	LOW 	HALF
LOW 	HIGH	QUARTER
HIGH	HIGH	EIGHTH
*/
#define DRIVER1_EN PD2 // active LOW
#define DRIVER1_STEP PD3 // LOW->HIGH
#define DRIVER1_DIR PD4
#define DRIVER1_RST PD5 // active LOW => must be HIGH
#define DRIVER1_SLP PD6 // active LOW => must be HIGH
#define DRIVER1_PFD PD7 // percent fast decay


#define DRIVER2_MS1 PB0
#define DRIVER2_MS2 PB1
#define DRIVER2_EN PB2 // active LOW
#define DRIVER2_STEP PB3 // LOW->HIGH
#define DRIVER2_DIR PB4
#define DRIVER2_RST PB5 // active LOW => must be HIGH
#define DRIVER2_SLP PB6 // active LOW => must be HIGH
#define DRIVER2_PFD PB7 // percent fast decay

#define MAX_X 1000
#define MAX_Y 1000
#define MIN_X 0
#define MIN_Y 0

// pentru motorul prost : negru + albastru ||| mov + gri (pt firele de extindere); alb - nefolosit
// pentru celalalt: maro verde ||| gri portocaliu (pentru firele de extindere)

#define HIGH 1
#define LOW 0


int step_x = 0; // must be in [MIN_X, MAX_X]
int step_y = 0; // must be in [MIN_Y, MAX_Y]


void init_ports()
{
	DDRB = 0xFF; // output
	PORTB = 0; // pull low

	DDRD = 0xFF; // output
	PORTD = 0; // pull low
	PORTD |= (1 << DRIVER1_RST) | (1 << DRIVER1_SLP);

	DDRB = 0xFF; // output
	PORTB = 0; // pull low
	PORTB |= (1 << DRIVER2_RST) | (1 << DRIVER2_SLP);
}

void stepY(bool dir) {
	if (dir)
		PORTD |= (1 << DRIVER1_DIR);
	else PORTD &= ~(1 << DRIVER1_DIR);

	PORTD |= (1 << DRIVER1_STEP);
	_delay_ms(1);
	PORTD &= ~(1 << DRIVER1_STEP);
	_delay_ms(1);
}

void stepX(bool dir) {
	if (dir)
		PORTB |= (1 << DRIVER2_DIR);
	else PORTB &= ~(1 << DRIVER2_DIR);

	PORTB |= (1 << DRIVER2_STEP);
	_delay_ms(1);
	PORTB &= ~(1 << DRIVER2_STEP);
	_delay_ms(1);
}



uint8_t adresa_lcd = 0x00;

int main()
{
	char c;
	init_ports();
	LCD_init();
	DDRC |= (1 << PC7); // simulate ground for contrast
	PORTC &= ~(1 << PC7);
//	PORTD &= ~(1 << DRIVER1_SLP); // disable stepper

	LCD_putCharAt(0x00, '-');
	/* Set eigth step */
	PORTD |= (1 << DRIVER1_MS1) | (1 << DRIVER1_MS2);
//	PORTB |= (1 << DRIVER2_MS1) | (1 << DRIVER2_MS2);

	while(1)
	{
		c = readKey();
		if (c == '4')
			stepX(false);
		if (c == '6')
			stepX(true);
		if (c == '2')
			stepY(false);
		if (c == '8')
			stepY(true);
		if (c)
			LCD_putCharAt(adresa_lcd++, c);
		if (adresa_lcd == 0x10)
			adresa_lcd = 0x40;
		if (adresa_lcd == 0x50)
			adresa_lcd = 0x00;
	}
	return 0;
}
